# Py2N

Asynchronous library to control [2N® devices](https://https://www.2n.com)

**This library is under development**

## Requirements

- Python >= 3.9
- aiohttp

## Install
```bash
pip install py2n
```
